@@ -464,11 +464,18 @@ def picking_details(request_id):
         $ref: "#/definitions/Error message"
     """
     picking = PickingRequest(request_id)
-    response = picking.details()['content']
-    # API_LOGS.logger.info(response)
+    response = picking.details()
+
+    if response["status"] != 200:
+        status = response["status"]
+        data =  {}
+    else:
+        status = 200
+        data =  response["content"]
+
     response = {
-        "status": 200,
-        "data": response
+        "status": status,
+        "data": data
         }
 
     return jsonify(response)
